==> nomachine-8.7.1-1-x86_64.pkg.tar.zst: NX/lib/perl/nxnode/NXUPnP.pm <==
############################################################################
#                                                                          #
#  Copyright (c) 2001, 2023 NoMachine, http://www.nomachine.com.           #
#                                                                          #
#  NXNODE, NX protocol compression and NX extensions to this software      #
#  are copyright of NoMachine. Redistribution and use of the present       #
#  software is allowed according to terms specified in the file LICENSE    #
#  which comes in the source distribution.                                 #
#                                                                          #
#  Check http://www.nomachine.com/licensing.html for applicability.        #
#                                                                          #
#  NX and NoMachine are trademarks of NoMachine S.a.r.l.                   #
#                                                                          #
#  All rights reserved.                                                    #
#                                                                          #
############################################################################
package NXUPnP;no warnings;($pfProtocol=(""));($portInternal=(""));(
$portExternal=(""));($protocol="\x55\x44\x50");($duration=(0x114f+ 2818-0x19f9))
;sub BEGIN{require warnings;do{"\x77\x61\x72\x6e\x69\x6e\x67\x73"->import};}sub 
addRule{if ((not ($GLOBAL::EnableUPnP))){Logger::debug (
"\x4e\x58\x55\x50\x6e\x50\x20\x69\x73\x20\x64\x69\x73\x61\x62\x6c\x65\x64\x20\x69\x6e\x20\x6e\x6f\x64\x65\x20\x63\x6f\x6e\x66\x69\x67\x75\x72\x61\x74\x69\x6f\x6e\x2e"
);return ((0x00a6+ 7698-0x1eb8));}Logger::debug (((((((((
"\x54\x72\x79\x69\x6e\x67\x20\x74\x6f\x20\x61\x64\x64\x20\x70\x6f\x72\x74\x20\x66\x6f\x72\x77\x61\x72\x64\x69\x6e\x67\x20\x72\x75\x6c\x65\x3a\x20"
.$portExternal)."\x20\x2d\x3e\x20").$portInternal)."\x20\x28").$protocol).
"\x29\x20\x5b").$duration)."\x5d\x2e"));if ((($portInternal eq (""))or (
$portExternal eq ("")))){Logger::debug (
"\x53\x6b\x69\x70\x70\x65\x64\x20\x61\x64\x64\x69\x6e\x67\x20\x70\x6f\x72\x74\x20\x66\x6f\x72\x77\x61\x72\x64\x69\x6e\x67\x20\x72\x75\x6c\x65\x73"
);return ((0x0596+ 2042-0x0d90));}(my (@command)=());(my ($std_err,$std_out,
$ret_val)=((""),(""),("")));if (((not (defined ($pfProtocol)))or ($pfProtocol eq
 ("")))){Logger::debug (
"\x41\x75\x74\x6f\x64\x65\x74\x65\x63\x74\x69\x6e\x67\x20\x70\x6f\x72\x74\x20\x66\x6f\x72\x77\x61\x72\x64\x69\x6e\x67\x20\x70\x72\x6f\x74\x6f\x63\x6f\x6c"
);(@command=($GLOBAL::CommandNXUPNP,"\x2d\x70"));(($std_err,$std_out,$ret_val)=
main::run_command ((\@command)));($pfProtocol=$std_out);chomp ($pfProtocol);}
else{Logger::debug ((
"\x50\x72\x69\x76\x69\x64\x65\x64\x20\x70\x6f\x72\x74\x20\x66\x6f\x72\x77\x61\x72\x64\x69\x6e\x67\x20\x70\x72\x6f\x74\x6f\x63\x6f\x6c\x3a\x20"
.$pfProtocol));($ret_val=(0x0f99+ 1431-0x152f));}if (($ret_val eq "\x30")){if ((
($pfProtocol eq "\x75\x70\x6e\x70")or ($pfProtocol eq "\x6e\x61\x74\x70\x6d\x70"
))){if (($pfProtocol eq "\x75\x70\x6e\x70")){(@command=($GLOBAL::CommandNXUPNP,
"\x2d\x58",$pfProtocol,"\x2d\x72",$portExternal,$protocol,$duration));}else{(
@command=($GLOBAL::CommandNXUPNP,"\x2d\x58",$pfProtocol,"\x2d\x61",
"\x31\x32\x37\x2e\x30\x2e\x30\x2e\x31",$portExternal,$portInternal,$protocol,
$duration));}(($std_err,$std_out,$ret_val)=main::run_command ((\@command)));if (
($ret_val eq "\x31")){Logger::warning (
"\x43\x61\x6e\x6e\x6f\x74\x20\x61\x64\x64\x20\x70\x6f\x72\x74\x20\x66\x6f\x72\x77\x61\x72\x64\x6e\x69\x6e\x67\x20\x72\x75\x6c\x65\x2e"
);return ((0x08cf+ 2589-0x12ec));}else{Logger::debug (((((((
"\x50\x6f\x72\x74\x20\x66\x6f\x72\x77\x61\x72\x64\x69\x6e\x67\x20\x72\x75\x6c\x65\x20\x73\x75\x63\x63\x65\x73\x73\x66\x75\x6c\x6c\x79\x20\x61\x64\x64\x65\x64\x3a\x20"
.$portExternal)."\x20\x2d\x3e\x20").$portInternal).
"\x2c\x20\x70\x72\x6f\x74\x6f\x63\x6f\x6c\x3a\x20").$protocol)."\x2e"));return (
(0x10b7+ 106-0x1121));}}else{Logger::warning (
"\x43\x61\x6e\x6e\x6f\x74\x20\x64\x65\x74\x65\x72\x6d\x69\x6e\x65\x20\x70\x6f\x72\x74\x20\x66\x6f\x72\x77\x61\x72\x64\x69\x6e\x67\x20\x70\x72\x6f\x74\x6f\x63\x6f\x6c\x2e"
);return ((0x03aa+ 8976-0x26ba));}}else{Logger::warning (
"\x50\x6f\x72\x74\x20\x66\x6f\x72\x77\x61\x72\x64\x69\x6e\x67\x20\x70\x72\x6f\x74\x6f\x63\x6f\x6c\x3a\x20\x6e\x6f\x74\x20\x65\x6e\x61\x62\x6c\x65\x64\x2e"
);return ((0x10b9+ 4115-0x20cc));}return ((0x1389+ 1313-0x18aa));}sub 
refreshRule{addRule ($portExternal,$portNternal,$protocol,$duration,$pfProtocol)
;}sub removeRule{if ((not ($GLOBAL::EnableUPnP))){return ((0x0dad+ 4450-0x1f0f))
;}if ((($portInternal eq (""))or ($portExternal eq ("")))){Logger::debug (
"\x53\x6b\x69\x70\x70\x65\x64\x20\x72\x65\x6d\x6f\x76\x69\x6e\x67\x20\x70\x6f\x72\x74\x20\x66\x6f\x72\x77\x61\x72\x64\x69\x6e\x67\x20\x72\x75\x6c\x65\x73"
);return ((0x0b18+ 5822-0x21d6));}Logger::debug (((((((
"\x52\x65\x6d\x6f\x76\x69\x6e\x67\x20\x70\x6f\x72\x74\x20\x66\x6f\x72\x77\x61\x72\x64\x69\x6e\x67\x20\x72\x75\x6c\x65\x20"
.$portExternal)."\x20\x28").$protocol)."\x29\x20\x5b").$pfProtocol)."\x5d\x2e"))
;(my (@command)=());if (($pfProtocol eq "\x75\x70\x6e\x70")){(@command=(
$GLOBAL::CommandNXUPNP,"\x2d\x58",$pfProtocol,"\x2d\x64",$portExternal,$protocol
));}elsif (($pfProtocol eq "\x6e\x61\x74\x70\x6d\x70")){(@command=(
$GLOBAL::CommandNXUPNP,"\x2d\x58",$pfProtocol,"\x2d\x61",
"\x31\x32\x37\x2e\x30\x2e\x30\x2e\x31",$portExternal,$portExternal,$rotocol,
(0x0006+ 5382-0x150c)));}else{Logger::warning (((
"\x43\x61\x6e\x6e\x6f\x74\x20\x72\x65\x6d\x6f\x76\x65\x20\x70\x6f\x72\x74\x20\x66\x6f\x72\x77\x61\x72\x64\x69\x6e\x67\x20\x72\x75\x6c\x65\x3a\x20\x77\x72\x6f\x6e\x67\x20\x70\x72\x6f\x74\x6f\x63\x6f\x6c\x20\x5b"
.$pfProtocol)."\x5d\x2e"));return ((0x013d+ 7092-0x1cf0));}(my ($std_err,
$std_out,$ret_val)=main::run_command ((\@command)));if (($ret_val eq "\x30")){
Logger::warning (((((
"\x50\x6f\x72\x74\x20\x66\x6f\x72\x77\x61\x72\x64\x69\x6e\x67\x20\x72\x75\x6c\x65\x20\x73\x75\x63\x63\x65\x73\x73\x66\x75\x6c\x6c\x79\x20\x72\x65\x6d\x6f\x76\x65\x64\x3a\x20"
.$portExternal)."\x20\x28").$protocol)."\x29\x2e"));return (
(0x17b5+ 3416-0x250d));}else{Logger::warning (
"\x43\x61\x6e\x6e\x6f\x74\x20\x72\x65\x6d\x6f\x76\x65\x20\x70\x6f\x72\x74\x20\x66\x6f\x72\x77\x61\x72\x64\x69\x6e\x67\x20\x72\x75\x6c\x65\x2e"
);return ((0x0501+ 1911-0x0c77));}return ((0x047b+ 8179-0x246e));}sub 
setportInternal{(my $port=shift (@_));($portInternal=$port);}sub setportExternal
{(my $port=shift (@_));($portExternal=$port);}sub handleUdpDescriptor{(my $line=
shift (@_));Logger::debug (((
"\x48\x61\x6e\x64\x6c\x65\x20\x70\x61\x73\x73\x20\x55\x44\x50\x20\x68\x61\x6e\x64\x6c\x65\x20\x27"
.$line)."\x27\x2e"));main::parse_arguments ($line);main::nxwrite (
main::nxgetSTDOUT (),"\x72\x65\x61\x64\x79\x0a");(my $pid=$GLOBAL::parameters{
"\x75\x64\x70\x50\x69\x64"});(my $fd=$GLOBAL::parameters{"\x75\x64\x70\x46\x64"}
);(my $path=$GLOBAL::parameters{"\x75\x64\x70\x50\x61\x74\x68"});(my $cookie=
$GLOBAL::parameters{"\x75\x64\x70\x43\x6f\x6f\x6b\x69\x65"});(my $udpHandle=
Common::NXDescriptor::acquire ($pid,$fd,$path,$cookie));if (($udpHandle<
(0x1808+ 2692-0x228c))){Logger::warning (((((
"\x4e\x58\x55\x64\x70\x3a\x20\x46\x61\x69\x6c\x65\x64\x20\x74\x6f\x20\x61\x63\x71\x75\x69\x72\x65\x20\x55\x44\x50\x20\x68\x61\x6e\x64\x6c\x65\x20\x66\x72\x6f\x6d\x20\x73\x65\x72\x76\x65\x72\x20\x27"
.$pid)."\x27\x20\x61\x6e\x64\x20\x70\x61\x74\x68\x20\x27").$path)."\x27\x2e"));}
return ($udpHandle);}return ((0x0514+ 2220-0x0dbf));

==> nomachine-8.8.1-1-x86_64.pkg.tar.zst: NX/lib/perl/nxnode/NXUPnP.pm <==
############################################################################
#                                                                          #
#  Copyright (c) 2001, 2023 NoMachine, http://www.nomachine.com.           #
#                                                                          #
#  NXNODE, NX protocol compression and NX extensions to this software      #
#  are copyright of NoMachine. Redistribution and use of the present       #
#  software is allowed according to terms specified in the file LICENSE    #
#  which comes in the source distribution.                                 #
#                                                                          #
#  Check http://www.nomachine.com/licensing.html for applicability.        #
#                                                                          #
#  NX and NoMachine are trademarks of NoMachine S.a.r.l.                   #
#                                                                          #
#  All rights reserved.                                                    #
#                                                                          #
############################################################################
package NXUPnP;no warnings;($pfProtocol=(""));($portInternal=(""));(
$portExternal=(""));($protocol="\x55\x44\x50");($duration=600);sub BEGIN{require
 warnings;do{"\x77\x61\x72\x6e\x69\x6e\x67\x73"->import};}sub addRule{if ((not (
$GLOBAL::EnableUPnP))){Logger::debug (
"\x4e\x58\x55\x50\x6e\x50\x20\x69\x73\x20\x64\x69\x73\x61\x62\x6c\x65\x64\x20\x69\x6e\x20\x6e\x6f\x64\x65\x20\x63\x6f\x6e\x66\x69\x67\x75\x72\x61\x74\x69\x6f\x6e\x2e"
);return ((0x165b+ 2783-0x213a));}Logger::debug (((((((((
"\x54\x72\x79\x69\x6e\x67\x20\x74\x6f\x20\x61\x64\x64\x20\x70\x6f\x72\x74\x20\x66\x6f\x72\x77\x61\x72\x64\x69\x6e\x67\x20\x72\x75\x6c\x65\x3a\x20"
.$portExternal)."\x20\x2d\x3e\x20").$portInternal)."\x20\x28").$protocol).
"\x29\x20\x5b").$duration)."\x5d\x2e"));if ((($portInternal eq (""))or (
$portExternal eq ("")))){Logger::debug (
"\x53\x6b\x69\x70\x70\x65\x64\x20\x61\x64\x64\x69\x6e\x67\x20\x70\x6f\x72\x74\x20\x66\x6f\x72\x77\x61\x72\x64\x69\x6e\x67\x20\x72\x75\x6c\x65\x73"
);return ((0x2170+ 855-0x24c7));}(my (@command)=());(my ($std_err,$std_out,
$ret_val)=((""),(""),("")));if (((not (defined ($pfProtocol)))or ($pfProtocol eq
 ("")))){Logger::debug (
"\x41\x75\x74\x6f\x64\x65\x74\x65\x63\x74\x69\x6e\x67\x20\x70\x6f\x72\x74\x20\x66\x6f\x72\x77\x61\x72\x64\x69\x6e\x67\x20\x70\x72\x6f\x74\x6f\x63\x6f\x6c"
);(@command=($GLOBAL::CommandNXUPNP,"\x2d\x70"));(($std_err,$std_out,$ret_val)=
main::run_command ((\@command)));($pfProtocol=$std_out);chomp ($pfProtocol);}
else{Logger::debug ((
"\x50\x72\x69\x76\x69\x64\x65\x64\x20\x70\x6f\x72\x74\x20\x66\x6f\x72\x77\x61\x72\x64\x69\x6e\x67\x20\x70\x72\x6f\x74\x6f\x63\x6f\x6c\x3a\x20"
.$pfProtocol));($ret_val=(0x0a73+ 730-0x0d4c));}if (($ret_val eq "\x30")){if (((
$pfProtocol eq "\x75\x70\x6e\x70")or ($pfProtocol eq "\x6e\x61\x74\x70\x6d\x70")
)){if (($pfProtocol eq "\x75\x70\x6e\x70")){(@command=($GLOBAL::CommandNXUPNP,
"\x2d\x58",$pfProtocol,"\x2d\x72",$portExternal,$protocol,$duration));}else{(
@command=($GLOBAL::CommandNXUPNP,"\x2d\x58",$pfProtocol,"\x2d\x61",
"\x31\x32\x37\x2e\x30\x2e\x30\x2e\x31",$portExternal,$portInternal,$protocol,
$duration));}(($std_err,$std_out,$ret_val)=main::run_command ((\@command)));if (
($ret_val eq "\x31")){Logger::warning (
"\x43\x61\x6e\x6e\x6f\x74\x20\x61\x64\x64\x20\x70\x6f\x72\x74\x20\x66\x6f\x72\x77\x61\x72\x64\x6e\x69\x6e\x67\x20\x72\x75\x6c\x65\x2e"
);return ((0x0f4c+ 2499-0x190f));}else{Logger::debug (((((((
"\x50\x6f\x72\x74\x20\x66\x6f\x72\x77\x61\x72\x64\x69\x6e\x67\x20\x72\x75\x6c\x65\x20\x73\x75\x63\x63\x65\x73\x73\x66\x75\x6c\x6c\x79\x20\x61\x64\x64\x65\x64\x3a\x20"
.$portExternal)."\x20\x2d\x3e\x20").$portInternal).
"\x2c\x20\x70\x72\x6f\x74\x6f\x63\x6f\x6c\x3a\x20").$protocol)."\x2e"));return (
(0x022b+ 3619-0x104e));}}else{Logger::warning (
"\x43\x61\x6e\x6e\x6f\x74\x20\x64\x65\x74\x65\x72\x6d\x69\x6e\x65\x20\x70\x6f\x72\x74\x20\x66\x6f\x72\x77\x61\x72\x64\x69\x6e\x67\x20\x70\x72\x6f\x74\x6f\x63\x6f\x6c\x2e"
);return ((0x0826+ 1917-0x0fa3));}}else{Logger::warning (
"\x50\x6f\x72\x74\x20\x66\x6f\x72\x77\x61\x72\x64\x69\x6e\x67\x20\x70\x72\x6f\x74\x6f\x63\x6f\x6c\x3a\x20\x6e\x6f\x74\x20\x65\x6e\x61\x62\x6c\x65\x64\x2e"
);return ((0x0c34+ 3256-0x18ec));}return ((0x0157+ 2993-0x0d08));}sub 
refreshRule{addRule ($portExternal,$portNternal,$protocol,$duration,$pfProtocol)
;}sub removeRule{if ((not ($GLOBAL::EnableUPnP))){return ((0x168a+ 1569-0x1cab))
;}if ((($portInternal eq (""))or ($portExternal eq ("")))){Logger::debug (
"\x53\x6b\x69\x70\x70\x65\x64\x20\x72\x65\x6d\x6f\x76\x69\x6e\x67\x20\x70\x6f\x72\x74\x20\x66\x6f\x72\x77\x61\x72\x64\x69\x6e\x67\x20\x72\x75\x6c\x65\x73"
);return ((0x167c+ 2151-0x1ee3));}Logger::debug (((((((
"\x52\x65\x6d\x6f\x76\x69\x6e\x67\x20\x70\x6f\x72\x74\x20\x66\x6f\x72\x77\x61\x72\x64\x69\x6e\x67\x20\x72\x75\x6c\x65\x20"
.$portExternal)."\x20\x28").$protocol)."\x29\x20\x5b").$pfProtocol)."\x5d\x2e"))
;(my (@command)=());if (($pfProtocol eq "\x75\x70\x6e\x70")){(@command=(
$GLOBAL::CommandNXUPNP,"\x2d\x58",$pfProtocol,"\x2d\x64",$portExternal,$protocol
));}elsif (($pfProtocol eq "\x6e\x61\x74\x70\x6d\x70")){(@command=(
$GLOBAL::CommandNXUPNP,"\x2d\x58",$pfProtocol,"\x2d\x61",
"\x31\x32\x37\x2e\x30\x2e\x30\x2e\x31",$portExternal,$portExternal,$rotocol,
(0x22b1+ 855-0x2608)));}else{Logger::warning (((
"\x43\x61\x6e\x6e\x6f\x74\x20\x72\x65\x6d\x6f\x76\x65\x20\x70\x6f\x72\x74\x20\x66\x6f\x72\x77\x61\x72\x64\x69\x6e\x67\x20\x72\x75\x6c\x65\x3a\x20\x77\x72\x6f\x6e\x67\x20\x70\x72\x6f\x74\x6f\x63\x6f\x6c\x20\x5b"
.$pfProtocol)."\x5d\x2e"));return ((0x09b1+ 6739-0x2403));}(my ($std_err,
$std_out,$ret_val)=main::run_command ((\@command)));if (($ret_val eq "\x30")){
Logger::warning (((((
"\x50\x6f\x72\x74\x20\x66\x6f\x72\x77\x61\x72\x64\x69\x6e\x67\x20\x72\x75\x6c\x65\x20\x73\x75\x63\x63\x65\x73\x73\x66\x75\x6c\x6c\x79\x20\x72\x65\x6d\x6f\x76\x65\x64\x3a\x20"
.$portExternal)."\x20\x28").$protocol)."\x29\x2e"));return (
(0x1776+ 1001-0x1b5f));}else{Logger::warning (
"\x43\x61\x6e\x6e\x6f\x74\x20\x72\x65\x6d\x6f\x76\x65\x20\x70\x6f\x72\x74\x20\x66\x6f\x72\x77\x61\x72\x64\x69\x6e\x67\x20\x72\x75\x6c\x65\x2e"
);return ((0x0f4d+ 5403-0x2467));}return ((0x0216+ 7421-0x1f13));}sub 
setportInternal{(my $port=shift (@_));($portInternal=$port);}sub setportExternal
{(my $port=shift (@_));($portExternal=$port);}sub handleUdpDescriptor{(my $line=
shift (@_));Logger::debug (((
"\x48\x61\x6e\x64\x6c\x65\x20\x70\x61\x73\x73\x20\x55\x44\x50\x20\x68\x61\x6e\x64\x6c\x65\x20\x27"
.$line)."\x27\x2e"));main::parse_arguments ($line);main::nxwrite (
main::nxgetSTDOUT (),"\x72\x65\x61\x64\x79\x0a");(my $pid=$GLOBAL::parameters{
"\x75\x64\x70\x50\x69\x64"});(my $fd=$GLOBAL::parameters{"\x75\x64\x70\x46\x64"}
);(my $path=$GLOBAL::parameters{"\x75\x64\x70\x50\x61\x74\x68"});(my $cookie=
$GLOBAL::parameters{"\x75\x64\x70\x43\x6f\x6f\x6b\x69\x65"});(my $udpHandle=
Common::NXDescriptor::acquire ($pid,$fd,$path,$cookie));if (($udpHandle<
(0x1d97+ 2022-0x257d))){Logger::warning (((((
"\x4e\x58\x55\x64\x70\x3a\x20\x46\x61\x69\x6c\x65\x64\x20\x74\x6f\x20\x61\x63\x71\x75\x69\x72\x65\x20\x55\x44\x50\x20\x68\x61\x6e\x64\x6c\x65\x20\x66\x72\x6f\x6d\x20\x73\x65\x72\x76\x65\x72\x20\x27"
.$pid)."\x27\x20\x61\x6e\x64\x20\x70\x61\x74\x68\x20\x27").$path)."\x27\x2e"));}
return ($udpHandle);}return ((0x14ff+ 282-0x1618));
